@@ -2,7 +2,7 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * Copyright (c) 1998-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
  * This file contains Original Code and/or Modifications of Original Code
  * as defined in and that are subject to the Apple Public Source License
@@ -274,8 +274,7 @@ protected:
 
 	void linkInterruptEndpoint(AppleEHCIQueueHead *pEHCIEndpointDescriptor);
 	void linkAsyncEndpoint(AppleEHCIQueueHead *CBED, AppleEHCIQueueHead *pEDHead);
-	void returnTransactions(AppleEHCIQueueHead *pED, 
-							EHCIGeneralTransferDescriptor *untilThisOne);
+	void returnTransactions(AppleEHCIQueueHead *pED, EHCIGeneralTransferDescriptor *untilThisOne);
 
     AppleEHCIQueueHead *AddEmptyCBEndPoint(
             UInt8 					functionAddress,
@@ -551,7 +550,7 @@ public:
             short				endpointNumber,
             short				direction);
 
-    IOReturn HandleEndpointAbort(short functionNumber, short endpointNumber, short direction);
+    IOReturn HandleEndpointAbort(short functionNumber, short endpointNumber, short direction, bool clearToggle);
     
     IOReturn GetRootHubDeviceDescriptor(IOUSBDeviceDescriptor *desc);
     IOReturn GetRootHubDescriptor(IOUSBHubDescriptor *desc);
